"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class RpcApi {
    constructor(nodeos_url, pools_contract) {
        this.nodeos_url = nodeos_url;
        this.pools_contract = pools_contract;
    }
    getCurrencyStats(payload) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetch(`${this.nodeos_url}/v1/chain/get_currency_stats`, {
                method: "POST",
                headers: { "Content-Type": "application/json" },
                body: JSON.stringify(payload),
            });
        });
    }
    getCurrencyBalance(payload) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetch(`${this.nodeos_url}/v1/chain/get_currency_balance`, {
                method: "POST",
                headers: { "Content-Type": "application/json" },
                body: JSON.stringify(payload),
            });
        });
    }
    getTableRows(payload) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetch(`${this.nodeos_url}/v1/chain/get_table_rows`, {
                method: "POST",
                headers: { "Content-Type": "application/json" },
                body: JSON.stringify(payload),
            });
        });
    }
    getPool(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            if (opts.id) {
                return this.getTableRows({
                    code: this.pools_contract,
                    scope: this.pools_contract,
                    table: "pools",
                    table_key: opts.id,
                });
            }
            else if (opts.code) {
                return this.getTableRows({
                    code: this.pools_contract,
                    scope: this.pools_contract,
                    table: "pools",
                    table_key: opts.code,
                    lower_bound: opts.code,
                    upper_bound: opts.code,
                    key_type: "i64",
                    index_position: "secondary",
                });
            }
            else if (opts.owner) {
                return this.getTableRows({
                    code: this.pools_contract,
                    scope: this.pools_contract,
                    table: "pools",
                    table_key: opts.owner,
                    lower_bound: opts.owner,
                    upper_bound: opts.owner,
                    key_type: "name",
                    index_position: "secondary",
                });
            }
            else if (opts.description_sha256) {
                return this.getTableRows({
                    code: this.pools_contract,
                    scope: this.pools_contract,
                    table: "pools",
                    table_key: opts.description_sha256,
                    lower_bound: opts.description_sha256,
                    upper_bound: opts.description_sha256,
                    key_type: "sha256",
                    index_position: "fourth",
                });
            }
        });
    }
    getWhiteList(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            if (opts.user) {
                return this.getTableRows({
                    code: this.pools_contract,
                    scope: opts.pool_id,
                    table: "whitelist",
                    table_key: opts.user,
                });
            }
            else {
                return this.getTableRows({
                    code: this.pools_contract,
                    scope: opts.pool_id,
                    table: "whitelist",
                });
            }
        });
    }
}
exports.default = RpcApi;
